@@ -12,8 +12,7 @@ rtfNCA = function(fileName="Temp-NCA.rtf", concData, colSubj="Subject", colTime=
   maxy = max(concData[,colConc])
   miny = min(concData[concData[,colConc]>0,colConc])
 
-  IDs = sort(as.character(unique(concData[,colSubj])))
-  IDs = sort(as.numeric(unique(concData[,colSubj])))
+  IDs = unique(concData[,colSubj])
   nID = length(IDs)
   Res = vector()
   for (i in 1:nID) {
